==> freecad_0.13.2935-dfsg.orig.tar.xz: freecad-0.13.2935-dfsg/src/Mod/Complete/Gui/Resources/translations/Complete_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS>
  <context>
    <name>CmdCompleteConstraintAxle</name>
    <message>
      <location filename="../../Command.cpp" line="+42"/>
      <source>Complete</source>
      <translation>Complet</translation>
    </message>
    <message>
      <source>Constraint Axle...</source>
      <translation>Contrainte axiale...</translation>
    </message>
    <message>
      <source>set a axle constraint between two objects</source>
      <translation>définir une contrainte axiale entre deux objets</translation>
    </message>
  </context>
  <context>
    <name>Test_Test</name>
    <message>
      <location filename="../../Workbench.cpp" line="+57"/>
      <source>Self-test...</source>
      <translation>Auto-test...</translation>
    </message>
    <message>
      <source>Runs a self-test to check if the application works properly</source>
      <translation>Exécute un auto-test pour vérifier si l'application fonctionne correctement</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <source>Dr&amp;awing</source>
      <translation>&amp;Mise en plan</translation>
    </message>
    <message>
      <source>S&amp;ketch</source>
      <translation>Es&amp;quisse</translation>
    </message>
    <message>
      <source>&amp;Raytracing</source>
      <translation>&amp;Lancer de rayon</translation>
    </message>
    <message>
      <source>&amp;Drafting</source>
      <translation>&amp;Planche à dessin</translation>
    </message>
    <message>
      <source>Sketch based</source>
      <translation>À base d'esquisse</translation>
    </message>
    <message>
      <source>Primitives</source>
      <translation>Primitives</translation>
    </message>
    <message>
      <source>Parametric</source>
      <translation>Paramétrique</translation>
    </message>
    <message>
      <source>Object appearence</source>
      <translation>Apparence d'objet</translation>
    </message>
    <message>
      <source>Wire Tools</source>
      <translation>Outils filaires</translation>
    </message>
  </context>
</TS>

==> freecad_0.14.3702+dfsg.orig.tar.xz: freecad-0.14.3702/src/Mod/Complete/Gui/Resources/translations/Complete_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr" sourcelanguage="en">
  <context>
    <name>CmdCompleteConstraintAxle</name>
    <message>
      <location filename="../../Command.cpp" line="+42"/>
      <source>Complete</source>
      <translation>Complet</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Constraint Axle...</source>
      <translation>Contrainte axiale...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>set a axle constraint between two objects</source>
      <translation>définir une contrainte axiale entre deux objets</translation>
    </message>
  </context>
  <context>
    <name>Test_Test</name>
    <message>
      <location filename="../../Workbench.cpp" line="+57"/>
      <source>Self-test...</source>
      <translation>Auto-test...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Runs a self-test to check if the application works properly</source>
      <translation>Exécute un auto-test pour vérifier si l'application fonctionne correctement</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location line="-9"/>
      <source>Dr&amp;awing</source>
      <translation>&amp;Mise en plan</translation>
    </message>
    <message>
      <location line="-1"/>
      <source>S&amp;ketch</source>
      <translation>Es&amp;quisse</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>&amp;Raytracing</source>
      <translation>&amp;Lancer de rayon</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>&amp;Drafting</source>
      <translation>&amp;Planche à dessin</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Sketch based</source>
      <translation>À base d'esquisse</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Primitives</source>
      <translation>Primitives</translation>
    </message>
    <message>
      <source>Parametric</source>
      <translation type="obsolete">Paramétrique</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Object appearence</source>
      <translation>Apparence d'objet</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Wire Tools</source>
      <translation>Outils filaires</translation>
    </message>
  </context>
</TS>
